==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/s3/kotlin/inputs/BucketReplicationConfigurationRuleDestinationReplicationTimeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3.kotlin.inputs

import com.pulumi.aws.s3.inputs.BucketReplicationConfigurationRuleDestinationReplicationTimeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property minutes Threshold within which objects are to be replicated. The only valid value is `15`.
 * @property status The status of RTC. Either `Enabled` or `Disabled`.
 */
public data class BucketReplicationConfigurationRuleDestinationReplicationTimeArgs(
    public val minutes: Output<Int>? = null,
    public val status: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.s3.inputs.BucketReplicationConfigurationRuleDestinationReplicationTimeArgs> {
    override fun toJava():
        com.pulumi.aws.s3.inputs.BucketReplicationConfigurationRuleDestinationReplicationTimeArgs =
        com.pulumi.aws.s3.inputs.BucketReplicationConfigurationRuleDestinationReplicationTimeArgs.builder()
            .minutes(minutes?.applyValue({ args0 -> args0 }))
            .status(status?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BucketReplicationConfigurationRuleDestinationReplicationTimeArgs].
 */
@PulumiTagMarker
public class BucketReplicationConfigurationRuleDestinationReplicationTimeArgsBuilder internal
constructor() {
    private var minutes: Output<Int>? = null

    private var status: Output<String>? = null

    /**
     * @param value Threshold within which objects are to be replicated. The only valid value is `15`.
     */
    @JvmName("evbjebpqlgjmkkhb")
    public suspend fun minutes(`value`: Output<Int>) {
        this.minutes = value
    }

    /**
     * @param value The status of RTC. Either `Enabled` or `Disabled`.
     */
    @JvmName("ccdildnfookdsvqi")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Threshold within which objects are to be replicated. The only valid value is `15`.
     */
    @JvmName("iyxlmpqphajcofel")
    public suspend fun minutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param value The status of RTC. Either `Enabled` or `Disabled`.
     */
    @JvmName("edtkhflryijvmweb")
    public suspend fun status(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): BucketReplicationConfigurationRuleDestinationReplicationTimeArgs =
        BucketReplicationConfigurationRuleDestinationReplicationTimeArgs(
            minutes = minutes,
            status = status,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/s3/kotlin/inputs/BucketReplicationConfigurationRuleDestinationReplicationTimeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3.kotlin.inputs

import com.pulumi.aws.s3.inputs.BucketReplicationConfigurationRuleDestinationReplicationTimeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property minutes Threshold within which objects are to be replicated. The only valid value is `15`.
 * @property status Status of RTC. Either `Enabled` or `Disabled`.
 */
public data class BucketReplicationConfigurationRuleDestinationReplicationTimeArgs(
    public val minutes: Output<Int>? = null,
    public val status: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.s3.inputs.BucketReplicationConfigurationRuleDestinationReplicationTimeArgs> {
    override fun toJava(): com.pulumi.aws.s3.inputs.BucketReplicationConfigurationRuleDestinationReplicationTimeArgs =
        com.pulumi.aws.s3.inputs.BucketReplicationConfigurationRuleDestinationReplicationTimeArgs.builder()
            .minutes(minutes?.applyValue({ args0 -> args0 }))
            .status(status?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BucketReplicationConfigurationRuleDestinationReplicationTimeArgs].
 */
@PulumiTagMarker
public class BucketReplicationConfigurationRuleDestinationReplicationTimeArgsBuilder internal constructor() {
    private var minutes: Output<Int>? = null

    private var status: Output<String>? = null

    /**
     * @param value Threshold within which objects are to be replicated. The only valid value is `15`.
     */
    @JvmName("twucednxnrnexexs")
    public suspend fun minutes(`value`: Output<Int>) {
        this.minutes = value
    }

    /**
     * @param value Status of RTC. Either `Enabled` or `Disabled`.
     */
    @JvmName("lbhpvabgwguhfcev")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Threshold within which objects are to be replicated. The only valid value is `15`.
     */
    @JvmName("qoppjajhifmokyvr")
    public suspend fun minutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param value Status of RTC. Either `Enabled` or `Disabled`.
     */
    @JvmName("bdvqdcyyfedjqlaq")
    public suspend fun status(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): BucketReplicationConfigurationRuleDestinationReplicationTimeArgs =
        BucketReplicationConfigurationRuleDestinationReplicationTimeArgs(
            minutes = minutes,
            status = status,
        )
}
